@@ -213,8 +213,13 @@ class account_bank_statement(osv.osv):
                 amount = res_currency_obj.compute(cr, uid, st.currency.id,
                         company_currency_id, move.amount, context=context,
                         account=acc_cur)
+                if st.currency.id <> company_currency_id:
+                    amount_cur = res_currency_obj.compute(cr, uid, company_currency_id,
+                                st.currency.id, amount, context=context,
+                                account=acc_cur)
+                    val['amount_currency'] = -amount_cur
 
-                if move.account_id and move.account_id.currency_id:
+                if move.account_id and move.account_id.currency_id and move.account_id.currency_id.id <> company_currency_id:
                     val['currency_id'] = move.account_id.currency_id.id
                     if company_currency_id==move.account_id.currency_id.id:
                         amount_cur = move.amount
@@ -249,7 +254,6 @@ class account_bank_statement(osv.osv):
                 if st.currency.id <> company_currency_id:
                     amount_currency = move.amount
                     currency_id = st.currency.id
-
                 account_move_line_obj.create(cr, uid, {
                     'name': move.name,
                     'date': move.date,
@@ -278,7 +282,7 @@ class account_bank_statement(osv.osv):
                     torec += map(lambda x: x.id, move.reconcile_id.line_ids)
                     #try:
                     if abs(move.reconcile_amount-move.amount)<0.0001:
-                        account_move_line_obj.reconcile(cr, uid, torec, 'statement', context)
+                        account_move_line_obj.reconcile(cr, uid, torec, 'statement', writeoff_period_id=st.period_id.id, writeoff_journal_id=st.journal_id.id, context=context)
                     else:
                         account_move_line_obj.reconcile_partial(cr, uid, torec, 'statement', context)
                     #except:
@@ -431,7 +435,17 @@ class account_bank_statement_reconcile(osv.osv):
     def name_get(self, cursor, user, ids, context=None):
         res= []
         for o in self.browse(cursor, user, ids, context=context):
-            res.append((o.id, '[%.2f]' % (o.total_entry - o.total_new,)))
+            result = 0.0
+            res_currency = ''
+            for line in o.line_ids:
+                if line.amount_currency and line.currency_id:
+                    result += line.amount_currency
+                    res_currency = line.currency_id.code
+                else:
+                    result += line.debit - line.credit
+            if res_currency:
+                res_currency = ' ' + res_currency
+            res.append((o.id, '[%.2f'% (result - o.total_new,) + res_currency + ']' ))
         return res
 
     _columns = {
