@@ -1,7 +1,7 @@
 # -*- encoding: utf-8 -*-
 ##############################################################################
 #
-#    OpenERP, Open Source Management Solution	
+#    OpenERP, Open Source Management Solution
 #    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
 #    $Id$
 #
@@ -25,6 +25,7 @@ import netsvc
 from osv import fields, osv, orm
 import ir
 from mx import DateTime
+from tools.translate import _
 
 #----------------------------------------------------------
 # Auction Artists
@@ -75,7 +76,7 @@ class auction_dates(osv.osv):
         'acc_income': fields.many2one('account.account', 'Income Account', required=True),
         'acc_expense': fields.many2one('account.account', 'Expense Account', required=True),
         'adj_total': fields.function(_adjudication_get, method=True, string='Total Adjudication',store=True),
-        'state': fields.selection((('draft','Draft'),('close','Closed')),'Status',select=1, readonly=True),
+        'state': fields.selection((('draft','Draft'),('closed','Closed')),'Status',select=1, readonly=True),
         'account_analytic_id': fields.many2one('account.analytic.account', 'Analytic Account', required=True),
 
     }
@@ -627,7 +628,7 @@ class auction_lots(osv.osv):
                 continue
             partner_r=self.pool.get('res.partner')
             if not lot.ach_uid.id:
-                raise orm.except_orm('Missed buyer !', 'The object "%s" has no buyer assigned.' % (lot.name,))
+                raise orm.except_orm(_('Missed buyer !'), _('The object "%s" has no buyer assigned.') % (lot.name,))
             else:
                 partner_ref =lot.ach_uid.id
                 lot_name = lot.obj_num
@@ -635,7 +636,7 @@ class auction_lots(osv.osv):
                 contact_addr_id = res['contact']
                 invoice_addr_id = res['invoice']
                 if not invoice_addr_id:
-                    raise orm.except_orm('No Invoice Address', 'The Buyer "%s" has no Invoice Address.' % (contact_addr_id,))
+                    raise orm.except_orm(_('No Invoice Address'), _('The Buyer "%s" has no Invoice Address.') % (contact_addr_id,))
                 inv = {
                     'name': 'Auction proforma:' +lot.name,
                     'journal_id': lot.auction_id.journal_id.id,
@@ -754,13 +755,13 @@ class auction_lots(osv.osv):
                 continue
             partner_r=self.pool.get('res.partner')
             if not lot.ach_uid.id:
-                raise orm.except_orm('Missed buyer !', 'The object "%s" has no buyer assigned.' % (lot.name,))
+                raise orm.except_orm(_('Missed buyer !'), _('The object "%s" has no buyer assigned.') % (lot.name,))
             if (lot.auction_id.id,lot.ach_uid.id) in invoices:
                 inv_id = invoices[(lot.auction_id.id,lot.ach_uid.id)]
             else:
                 add = partner_r.read(cr, uid, [lot.ach_uid.id], ['address'])[0]['address']
                 if not len(add):
-                    raise orm.except_orm('Missed Address !', 'The Buyer has no Invoice Address.')
+                    raise orm.except_orm(_('Missed Address !'), _('The Buyer has no Invoice Address.'))
                 price = lot.obj_price or 0.0
                 lot_name =lot.obj_num
                 inv={
@@ -769,7 +770,7 @@ class auction_lots(osv.osv):
                     'journal_id': lot.auction_id.journal_id.id,
                     'partner_id': lot.ach_uid.id,
                     'type': 'out_invoice',
-                    
+
                 }
                 if invoice_number:
                     inv['number'] = invoice_number
@@ -998,7 +999,7 @@ class report_seller_auction(osv.osv):
                 select
                     adl.id as auction,
                     min(al.id) as id,
-                    adl.auction1 as date,
+                    to_char(adl.auction1, 'YYYY-MM-DD') as date,
                     ad.partner_id as seller,
                     count(al.id) as "object_number",
                     SUM(al.obj_price) as "total_price",
@@ -1036,7 +1037,7 @@ class report_seller_auction2(osv.osv):
         cr.execute('''create or replace view report_seller_auction2  as
             (select
                 min(al.id) as id,
-                adl.auction1 as date,
+                to_char(adl.auction1, 'YYYY-MM-DD') as date,
                 adl.id as auction,
                 ad.partner_id as seller,
                 sum(al.obj_price) as "sum_adj",
@@ -1072,7 +1073,7 @@ class report_auction_view2(osv.osv):
         cr.execute('''create or replace view report_auction_view2 as (
             select
                 ad.id as id,
-                ad.auction1 as date,
+                to_char(ad.auction1, 'YYYY-MM-DD') as date,
                 ad.id as "auction",
                 count(al.id) as "obj_number",
                 SUM(al.obj_price) as "sum_adj",
@@ -1165,7 +1166,7 @@ class report_auction_estimation_adj_category(osv.osv):
     _columns = {
             'lot_est1': fields.float('Minimum Estimation',select=2),
             'lot_est2': fields.float('Maximum Estimation',select=2),
-            'obj_price': fields.float('Adjudication price'),
+#            'obj_price': fields.float('Adjudication price'),
             'date': fields.date('Date', readonly=True,select=1),
             'lot_type': fields.selection(_type_get, 'Object Type', size=64),
             'adj_total': fields.float('Total Adjudication',select=2),
@@ -1309,11 +1310,11 @@ class report_object_encoded(osv.osv):
         'user_id':fields.many2one('res.users', 'User', select=1),
         'estimation': fields.float('Estimation',select=2),
         'date': fields.date('Create Date',  required=True),
-        'gross_revenue':fields.float('Gross revenue',readonly=True, select=2),
-        'net_revenue':fields.float('Net revenue',readonly=True, select=2),
-        'obj_margin':fields.float('Net margin', readonly=True, select=2),
+#        'gross_revenue':fields.float('Gross revenue',readonly=True, select=2),
+#        'net_revenue':fields.float('Net revenue',readonly=True, select=2),
+#        'obj_margin':fields.float('Net margin', readonly=True, select=2),
         'obj_ret':fields.integer('# obj ret', readonly=True, select=2),
-        'adj':fields.integer('Adj.', readonly=True, select=2),
+#        'adj':fields.integer('Adj.', readonly=True, select=2),
         'obj_num':fields.integer('# of Encoded obj.', readonly=True, select=2),
     }
     def init(self, cr):
