@@ -576,7 +576,7 @@ class hr_timesheet_sheet_sheet_day(osv.osv):
                 sheet_id,
                 total_timesheet,
                 total_attendance,
-                round(cast((total_attendance - total_timesheet) as Numeric),2) AS total_difference
+                cast(round(cast(total_attendance - total_timesheet as Numeric),2) as Double Precision) AS total_difference
             FROM
                 ((
                     SELECT
