@@ -26,6 +26,8 @@ import netsvc
 import mx.DateTime
 from mx.DateTime import RelativeDateTime, today, DateTime, localtime
 from tools import config
+from tools.translate import _
+
 class mrp_repair(osv.osv):
     _name = 'mrp.repair'
     _description = 'Repairs Order'
@@ -258,7 +260,7 @@ class mrp_repair(osv.osv):
             if repair.state in ('draft','cancel') or repair.invoice_id:
                 continue
             if not (repair.partner_id.id and repair.partner_invoice_id.id):
-                raise osv.except_osv('No partner !','You have to select a partner in the repair form ! ')
+                raise osv.except_osv(_('No partner !'),_('You have to select a partner in the repair form !'))
             comment=repair.quotation_notes
             if (repair.invoice_method != 'none'):
                 if group and repair.partner_invoice_id.id in invoices_group:
