@@ -520,7 +520,7 @@ class sale_order(osv.osv):
                         pending_deliveries = True
                 
                 if ((not line.procurement_id) or (line.procurement_id.state=='done')) and not pending_deliveries:
-                    finished = True
+#                    finished = True
                     if line.state != 'done':
                         write_done_ids.append(line.id)
                 else:
@@ -554,8 +554,8 @@ class sale_order(osv.osv):
             picking_id = False
             for line in order.order_line:
                 proc_id = False
-                date_planned = DateTime.now() + DateTime.RelativeDateTime(days=line.delay or 0.0)
-                date_planned = (date_planned - DateTime.RelativeDateTime(days=company.security_lead)).strftime('%Y-%m-%d %H:%M:%S')
+                date_planned = DateTime.now() + DateTime.DateTimeDeltaFromDays(line.delay or 0.0)
+                date_planned = (date_planned - DateTime.DateTimeDeltaFromDays(company.security_lead)).strftime('%Y-%m-%d %H:%M:%S')
                 if line.state == 'done':
                     continue
                 if line.product_id and line.product_id.product_tmpl_id.type in ('product', 'consu'):
