@@ -1,7 +1,7 @@
 # -*- encoding: utf-8 -*-
 ##############################################################################
 #
-#    OpenERP, Open Source Management Solution	
+#    OpenERP, Open Source Management Solution
 #    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
 #    $Id$
 #
@@ -20,7 +20,7 @@
 #
 ##############################################################################
 
-import base64 
+import base64
 import logging
 import os
 import security
@@ -29,7 +29,7 @@ import thread
 import threading
 import time
 import sys
-
+import platform
 from tools.translate import _
 import addons
 import ir
@@ -38,7 +38,7 @@ import pooler
 import release
 import sql_db
 import tools
-
+import locale
 logging.basicConfig()
 
 class db(netsvc.Service):
@@ -50,6 +50,7 @@ class db(netsvc.Service):
         self.exportMethod(self.drop)
         self.exportMethod(self.dump)
         self.exportMethod(self.restore)
+        self.exportMethod(self.rename)
         self.exportMethod(self.list)
         self.exportMethod(self.list_lang)
         self.exportMethod(self.change_admin_password)
@@ -59,6 +60,8 @@ class db(netsvc.Service):
         self.id = 0
         self.id_protect = threading.Semaphore()
 
+        self._pg_psw_env_var_is_set = False # on win32, pg_dump need the PGPASSWORD env var
+
     def create(self, password, db_name, demo, lang, user_password='admin'):
         security.check_super(password)
         self.id_protect.acquire()
@@ -78,6 +81,7 @@ class db(netsvc.Service):
             sql_db.close_db('template1')
         class DBInitialize(object):
             def __call__(self, serv, id, db_name, demo, lang, user_password='admin'):
+                cr = None
                 try:
                     serv.actions[id]['progress'] = 0
                     clean = False
@@ -162,21 +166,33 @@ class db(netsvc.Service):
                 logger.notifyChannel("web-services", netsvc.LOG_INFO,
                     'DROP DB: %s' % (db_name))
         finally:
+            cr.commit()
             cr.close()
             sql_db.close_db('template1')
         return True
 
+    def _set_pg_psw_env_var(self):
+        if os.name == 'nt' and not os.environ.get('PGPASSWORD', ''):
+            os.environ['PGPASSWORD'] = tools.config['db_password']
+            self._pg_psw_env_var_is_set = True
+
+    def _unset_pg_psw_env_var(self):
+        if os.name == 'nt' and self._pg_psw_env_var_is_set:
+            os.environ['PGPASSWORD'] = ''
+
     def dump(self, password, db_name):
         security.check_super(password)
         logger = netsvc.Logger()
 
-        cmd = ['pg_dump', '--format=c']
+        self._set_pg_psw_env_var()
+
+        cmd = ['pg_dump', '--format=c', '--no-owner']
         if tools.config['db_user']:
             cmd.append('--username=' + tools.config['db_user'])
         if tools.config['db_host']:
             cmd.append('--host=' + tools.config['db_host'])
         if tools.config['db_port']:
-            cmd.append('--port=' + tools.config['db_port'])
+            cmd.append('--port=' + str(tools.config['db_port']))
         cmd.append(db_name)
 
         stdin, stdout = tools.exec_pg_command_pipe(*tuple(cmd))
@@ -189,12 +205,17 @@ class db(netsvc.Service):
             raise Exception, "Couldn't dump database"
         logger.notifyChannel("web-services", netsvc.LOG_INFO,
                 'DUMP DB: %s' % (db_name))
+
+        self._unset_pg_psw_env_var()
+
         return base64.encodestring(data)
 
     def restore(self, password, db_name, data):
         security.check_super(password)
         logger = netsvc.Logger()
 
+        self._set_pg_psw_env_var()
+
         if self.db_exist(db_name):
             logger.notifyChannel("web-services", netsvc.LOG_WARNING,
                     'RESTORE DB: %s already exists' % (db_name,))
@@ -209,13 +230,13 @@ class db(netsvc.Service):
             cr.close()
             sql_db.close_db('template1')
 
-        cmd = ['pg_restore']
+        cmd = ['pg_restore', '--no-owner']
         if tools.config['db_user']:
             cmd.append('--username=' + tools.config['db_user'])
         if tools.config['db_host']:
             cmd.append('--host=' + tools.config['db_host'])
         if tools.config['db_port']:
-            cmd.append('--port=' + tools.config['db_port'])
+            cmd.append('--port=' + str(tools.config['db_port']))
         cmd.append('--dbname=' + db_name)
         args2 = tuple(cmd)
 
@@ -235,6 +256,36 @@ class db(netsvc.Service):
             raise Exception, "Couldn't restore database"
         logger.notifyChannel("web-services", netsvc.LOG_INFO,
                 'RESTORE DB: %s' % (db_name))
+
+        self._unset_pg_psw_env_var()
+
+        return True
+
+    def rename(self, password, old_name, new_name):
+        security.check_super(password)
+        sql_db.close_db(old_name)
+        logger = netsvc.Logger()
+
+        db = sql_db.db_connect('template1')
+        cr = db.serialized_cursor()
+        try:
+            try:
+                cr.execute('ALTER DATABASE "%s" RENAME TO "%s"' % (old_name, new_name))
+            except Exception, e:
+                logger.notifyChannel("web-services", netsvc.LOG_ERROR,
+                        'RENAME DB: %s -> %s failed:\n%s' % (old_name, new_name, e))
+                raise Exception("Couldn't rename database %s to %s: %s" % (old_name, new_name, e))
+            else:
+                fs = os.path.join(tools.config['root_path'], 'filestore')
+                if os.path.exists(os.path.join(fs, old_name)):
+                    os.rename(os.path.join(fs, old_name), os.path.join(fs, new_name))
+
+                logger.notifyChannel("web-services", netsvc.LOG_INFO,
+                    'RENAME DB: %s -> %s' % (old_name, new_name))
+        finally:
+            cr.commit()
+            cr.close()
+            sql_db.close_db('template1')
         return True
 
     def db_exist(self, db_name):
@@ -296,7 +347,7 @@ class db(netsvc.Service):
             try:
                 l.notifyChannel('migration', netsvc.LOG_INFO, 'migrate database %s' % (db,))
                 tools.config['update']['base'] = True
-                pooler.restart_pool(db, force_demo=False, update_module=True) 
+                pooler.restart_pool(db, force_demo=False, update_module=True)
             except except_orm, inst:
                 self.abortResponse(1, inst.name, 'warning', inst.value)
             except except_osv, inst:
@@ -322,6 +373,8 @@ class common(netsvc.Service):
         self.exportMethod(self.timezone_get)
         self.exportMethod(self.get_available_updates)
         self.exportMethod(self.get_migration_scripts)
+        self.exportMethod(self.get_server_environment)
+        self.exportMethod(self.login_message)
 
     def ir_set(self, db, uid, password, keys, args, name, value, replace=True, isobject=False):
         security.check(db, uid, password)
@@ -386,36 +439,36 @@ GNU Public Licence.
     def timezone_get(self, db, login, password):
         return time.tzname[0]
 
-    
+
     def get_available_updates(self, password, contract_id, contract_password):
         security.check_super(password)
         import tools.maintenance as tm
         try:
             rc = tm.remote_contract(contract_id, contract_password)
             if not rc.id:
-                raise tm.RemoteContractException('This contract does not exist or is not active') 
-            
+                raise tm.RemoteContractException('This contract does not exist or is not active')
+
             return rc.get_available_updates(rc.id, addons.get_modules_with_version())
 
         except tm.RemoteContractException, e:
             self.abortResponse(1, 'Migration Error', 'warning', str(e))
-        
+
 
     def get_migration_scripts(self, password, contract_id, contract_password):
         security.check_super(password)
         l = netsvc.Logger()
         import tools.maintenance as tm
-        try: 
+        try:
             rc = tm.remote_contract(contract_id, contract_password)
             if not rc.id:
-                raise tm.RemoteContractException('This contract does not exist or is not active') 
+                raise tm.RemoteContractException('This contract does not exist or is not active')
             if rc.status != 'full':
                 raise tm.RemoteContractException('Can not get updates for a partial contract')
 
             l.notifyChannel('migration', netsvc.LOG_INFO, 'starting migration with contract %s' % (rc.name,))
 
             zips = rc.retrieve_updates(rc.id, addons.get_modules_with_version())
-            
+
             from shutil import rmtree, copytree, copy
 
             backup_directory = os.path.join(tools.config['root_path'], 'backup', time.strftime('%Y-%m-%d-%H-%M'))
@@ -473,7 +526,41 @@ GNU Public Licence.
             tb_s = reduce(lambda x, y: x+y, traceback.format_exception( sys.exc_type, sys.exc_value, sys.exc_traceback))
             l.notifyChannel('migration', netsvc.LOG_ERROR, tb_s)
             raise
- 
+
+    def get_server_environment(self):
+        try:
+            rev_id = os.popen('bzr revision-info').read()
+        except Exception,e:
+             rev_id = 'Exception: %s\n' % (tools.ustr(e))
+
+        os_lang = '.'.join( [x for x in locale.getdefaultlocale() if x] )
+        if not os_lang:
+            os_lang = 'NOT SET'
+        environment = '\nEnvironment Information : \n' \
+                     'System : %s\n' \
+                     'OS Name : %s\n' \
+                     %(platform.platform(), platform.os.name)
+        if os.name == 'posix':
+          if platform.system() == 'Linux':
+             lsbinfo = os.popen('lsb_release -a').read()
+             environment += '%s'%(lsbinfo)
+          else:
+             environment += 'Your System is not lsb compliant\n'
+        environment += 'Operating System Release : %s\n' \
+                    'Operating System Version : %s\n' \
+                    'Operating System Architecture : %s\n' \
+                    'Operating System Locale : %s\n'\
+                    'Python Version : %s\n'\
+                    'OpenERP-Server Version : %s\n'\
+                    'Last revision No. & ID : %s'\
+                    %(platform.release(), platform.version(), platform.architecture()[0],
+                      os_lang, platform.python_version(),release.version,rev_id)
+        return environment
+    
+
+    def login_message(self):
+        return tools.config.get('login_message', False)
+
 common()
 
 class objects_proxy(netsvc.Service):
@@ -611,6 +698,7 @@ class report_spool(netsvc.Service):
                         'Exception: %s\n%s' % (str(exception), tb_s))
                 self._reports[id]['exception'] = ExceptionWithTraceback(tools.exception_to_unicode(exception), tb)
                 self._reports[id]['state'] = True
+            cr.commit()
             cr.close()
             return True
 
