@@ -256,10 +256,14 @@ form: module.record_id""" % (xml_id,)
         if len(d_search):
             ids = self.pool.get(d_model).search(cr,self.uid,eval(d_search))
         if len(d_id):
-            ids.append(self.id_get(cr, d_model, d_id))
+            try:
+                ids.append(self.id_get(cr, d_model, d_id))
+            except:
+                # d_id cannot be found. doesn't matter in this case
+                pass
         if len(ids):
             self.pool.get(d_model).unlink(cr, self.uid, ids)
-            #self.pool.get('ir.model.data')._unlink(cr, self.uid, d_model, ids, direct=True)
+            self.pool.get('ir.model.data')._unlink(cr, self.uid, d_model, ids, direct=True)
         return False
 
     def _tag_report(self, cr, rec, data_node=None):
@@ -872,7 +876,7 @@ def convert_xml_import(cr, module, xmlfile, idref=None, mode='init', noupdate=Fa
     except Exception, e:
         logger = netsvc.Logger()
         logger.notifyChannel('init', netsvc.LOG_ERROR, 'The XML file does not fit the required schema !')
-        logger.notifyChannel('init', netsvc.LOG_ERROR, relaxng.error_log.last_error)
+        logger.notifyChannel('init', netsvc.LOG_ERROR, misc.ustr(relaxng.error_log.last_error))
         raise
 
     if idref is None:
