@@ -94,14 +94,14 @@ def init_db(cr):
             id = cr.fetchone()[0]
             cr.execute('insert into ir_module_module \
                     (id, author, website, name, shortdesc, description, \
-                        category_id, state) \
-                    values (%s, %s, %s, %s, %s, %s, %s, %s)', (
+                        category_id, state, certificate) \
+                    values (%s, %s, %s, %s, %s, %s, %s, %s, %s)', (
                 id, info.get('author', ''),
                 info.get('website', ''), i, info.get('name', False),
-                info.get('description', ''), p_id, state))
+                info.get('description', ''), p_id, state, info.get('certificate')))
             cr.execute('insert into ir_model_data \
-                (name,model,module, res_id) values (%s,%s,%s,%s)', (
-                    'module_meta_information', 'ir.module.module', i, id))
+                (name,model,module, res_id, noupdate) values (%s,%s,%s,%s,%s)', (
+                    'module_meta_information', 'ir.module.module', i, id, True))
             dependencies = info.get('depends', [])
             for d in dependencies:
                 cr.execute('insert into ir_module_module_dependency \
@@ -302,7 +302,9 @@ def reverse_enumerate(l):
 #----------------------------------------------------------
 # Emails
 #----------------------------------------------------------
-def email_send(email_from, email_to, subject, body, email_cc=None, email_bcc=None, reply_to=False, attach=None, tinycrm=False, ssl=False, debug=False, subtype='plain'):
+def email_send(email_from, email_to, subject, body, email_cc=None, email_bcc=None, reply_to=False,
+               attach=None, tinycrm=False, ssl=False, debug=False, subtype='plain', x_headers=None):
+
     """Send an email."""
     import smtplib
     from email.MIMEText import MIMEText
@@ -312,25 +314,37 @@ def email_send(email_from, email_to, subject, body, email_cc=None, email_bcc=Non
     from email.Utils import formatdate, COMMASPACE
     from email.Utils import formatdate, COMMASPACE
     from email import Encoders
+    import netsvc
+
+    if x_headers is None:
+        x_headers = {}
 
     if not ssl:
         ssl = config.get('smtp_ssl', False)
 
+    if not email_from and not config['email_from']:
+        raise Exception("No Email sender by default, see config file")
+
     if not email_cc:
         email_cc = []
     if not email_bcc:
         email_bcc = []
 
     if not attach:
-        msg = MIMEText(body or '',_subtype=subtype,_charset='utf-8')
+        try:
+            msg = MIMEText(body.encode('utf8') or '',_subtype=subtype,_charset='utf-8')
+        except:
+            msg = MIMEText(body or '',_subtype=subtype,_charset='utf-8')
     else:
         msg = MIMEMultipart()
 
-    msg['Subject'] = Header(subject.decode('utf8'), 'utf-8')
+    msg['Subject'] = Header(ustr(subject), 'utf-8')
     msg['From'] = email_from
     del msg['Reply-To']
     if reply_to:
-        msg['Reply-To'] = msg['From']+', '+reply_to
+        msg['Reply-To'] = reply_to
+    else:
+        msg['Reply-To'] = msg['From']
     msg['To'] = COMMASPACE.join(email_to)
     if email_cc:
         msg['Cc'] = COMMASPACE.join(email_cc)
@@ -338,41 +352,71 @@ def email_send(email_from, email_to, subject, body, email_cc=None, email_bcc=Non
         msg['Bcc'] = COMMASPACE.join(email_bcc)
     msg['Date'] = formatdate(localtime=True)
 
+    # Add OpenERP Server information
+    msg['X-Generated-By'] = 'OpenERP (http://www.openerp.com)'
+    msg['X-OpenERP-Server-Host'] = socket.gethostname()
+    msg['X-OpenERP-Server-Version'] = release.version
+
+    # Add dynamic X Header
+    for key, value in x_headers.items():
+        msg['X-OpenERP-%s' % key] = str(value)
+
     if tinycrm:
         msg['Message-Id'] = "<%s-tinycrm-%s@%s>" % (time.time(), tinycrm, socket.gethostname())
 
     if attach:
-        msg.attach( MIMEText(body or '', _charset='utf-8', _subtype=subtype) )
-
+        try:
+            msg.attach(MIMEText(body.encode('utf8') or '',_subtype=subtype,_charset='utf-8'))
+        except:
+            msg.attach(MIMEText(body or '', _charset='utf-8', _subtype=subtype) )
         for (fname,fcontent) in attach:
             part = MIMEBase('application', "octet-stream")
             part.set_payload( fcontent )
             Encoders.encode_base64(part)
             part.add_header('Content-Disposition', 'attachment; filename="%s"' % (fname,))
             msg.attach(part)
+    
+    class WriteToLogger(object):
+        def __init__(self):
+            self.logger = netsvc.Logger()
+
+        def write(self, s):
+            self.logger.notifyChannel('email_send', netsvc.LOG_DEBUG, s)
+
     try:
+        oldstderr = smtplib.stderr
         s = smtplib.SMTP()
+        
+        try:
+            # in case of debug, the messages are printed to stderr.
+            if debug:
+                smtplib.stderr = WriteToLogger()
 
-        if debug:
-            s.debuglevel = 5
-        s.connect(config['smtp_server'], config['smtp_port'])
-        if ssl:
-            s.ehlo()
-            s.starttls()
-            s.ehlo()
+            s.set_debuglevel(int(bool(debug)))  # 0 or 1
+            
+            s.connect(config['smtp_server'], config['smtp_port'])
+            if ssl:
+                s.ehlo()
+                s.starttls()
+                s.ehlo()
 
-        if config['smtp_user'] or config['smtp_password']:
-            s.login(config['smtp_user'], config['smtp_password'])
+            if config['smtp_user'] or config['smtp_password']:
+                s.login(config['smtp_user'], config['smtp_password'])
+
+            s.sendmail(email_from, 
+                       flatten([email_to, email_cc, email_bcc]), 
+                       msg.as_string()
+                      )
+
+        finally:
+            s.quit()
+            if debug:
+                smtplib.stderr = oldstderr
 
-        s.sendmail(email_from, 
-                   flatten([email_to, email_cc, email_bcc]), 
-                   msg.as_string()
-                  )
-        s.quit()
     except Exception, e:
-        import logging
-        logging.getLogger().error(str(e))
+        netsvc.Logger().notifyChannel('email_send', netsvc.LOG_ERROR, e)
         return False
+    
     return True
 
 #----------------------------------------------------------
@@ -381,9 +425,10 @@ def email_send(email_from, email_to, subject, body, email_cc=None, email_bcc=Non
 # text must be latin-1 encoded
 def sms_send(user, password, api_id, text, to):
     import urllib
-    params = urllib.urlencode({'user': user, 'password': password, 'api_id': api_id, 'text': text, 'to':to})
-    #f = urllib.urlopen("http://api.clickatell.com/http/sendmsg", params)
-    f = urllib.urlopen("http://196.7.150.220/http/sendmsg", params)
+    url = "http://api.urlsms.com/SendSMS.aspx"
+    #url = "http://196.7.150.220/http/sendmsg"
+    params = urllib.urlencode({'UserID': user, 'Password': password, 'SenderID': api_id, 'MsgText': text, 'RecipientMobileNo':to})
+    f = urllib.urlopen(url+"?"+params)
     # FIXME: Use the logger if there is an error
     return True
 
@@ -559,9 +604,16 @@ class cache(object):
         """
         
         def to_tuple(d):
-            i = d.items()
-            i.sort(key=lambda (x,y): x)
-            return tuple(i)
+            pairs = d.items()
+            pairs.sort(key=lambda (k,v): k)
+            for i, (k, v) in enumerate(pairs):
+                if isinstance(v, dict):
+                    pairs[i] = (k, to_tuple(v))
+                if isinstance(v, (list, set)):
+                    pairs[i] = (k, tuple(v))
+                elif not is_hashable(v):
+                    pairs[i] = (k, repr(v))
+            return tuple(pairs)
 
         if not self.multi:
             key = (('dbname', dbname),) + to_tuple(kwargs2)
@@ -578,12 +630,6 @@ class cache(object):
         kwargs2 = self.fun_default_values.copy()
         kwargs2.update(kwargs)
         kwargs2.update(dict(zip(self.fun_arg_names, args[self.skiparg-2:])))
-        for k in kwargs2:
-            if isinstance(kwargs2[k], (list, dict, set)):
-                kwargs2[k] = tuple(kwargs2[k])
-            elif not is_hashable(kwargs2[k]):
-                kwargs2[k] = repr(kwargs2[k])
-
         return kwargs2
     
     def clear(self, dbname, *args, **kwargs):
@@ -619,9 +665,9 @@ class cache(object):
             if time.time()-self.timeout > self.lasttime:
                 self.lasttime = time.time()
                 t = time.time()-self.timeout 
-                for key in self.cache.keys():
-                    if self.cache[key][1]<t:
-                        del self.cache[key]
+                old_keys = [key for key in self.cache if self.cache[key][1] < t]
+                for key in old_keys:
+                    del self.cache[key]
 
             kwargs2 = self._unify_args(*args, **kwargs)
 
@@ -637,7 +683,7 @@ class cache(object):
                 if self.multi:
                     kwargs2[self.multi] = notincache.keys()
                 
-                result2 = fn(self2, cr, *args[2:self.skiparg], **kwargs2)
+                result2 = fn(self2, cr, *args[:self.skiparg-2], **kwargs2)
                 if not self.multi:
                     key = notincache[None]
                     self.cache[key] = (result2, time.time())
@@ -737,12 +783,12 @@ def get_languages():
         'de_DE': u'German / Deutsch',
         'el_EL': u'Greek / Ελληνικά',
         'en_CA': u'English (CA)',
-        'en_EN': u'English (default)',
         'en_GB': u'English (UK)',
         'en_US': u'English (US)',
         'es_AR': u'Spanish (AR) / Español (AR)',
         'es_ES': u'Spanish / Español',
         'et_EE': u'Estonian / Eesti keel',
+        'fi_FI': u'Finland / Suomi',
         'fr_BE': u'French (BE) / Français (BE)',
         'fr_CH': u'French (CH) / Français (CH)',
         'fr_FR': u'French / Français',
@@ -759,11 +805,14 @@ def get_languages():
         'ro_RO': u'Romanian / limba română',
         'ru_RU': u'Russian / русский язык',
         'sl_SL': u'Slovenian / slovenščina',
+        'sq_AL': u'Albanian / Shqipëri',
         'sv_SE': u'Swedish / svenska',
         'tr_TR': u'Turkish / Türkçe',
-        'uk_UK': u'Ukrainian / украї́нська мо́ва',
-        'zh_CN': u'Chinese (CN) / 简体中文' ,
+        'vi_VN': u'Vietnam / Cộng hòa xã hội chủ nghĩa Việt Nam',
+        'uk_UA': u'Ukrainian / украї́нська мо́ва',
+        'zh_CN': u'Chinese (CN) / 简体中文',
         'zh_TW': u'Chinese (TW) / 正體字',
+        'th_TH': u'Thai / ภาษาไทย',
     }
     return languages
 
